API docs for “spamfighter.rules.validate.regexpCheck”

# Class s.r.v.regexpCheck(object):

Part of spamfighter.rules.validate View Source View In Hierarchy

Правило проверки текст сообщение на соответствие регулярному выражению.

Instance Variables | compiledRe | скомпилированное регулярное выражение (type: `re` )

Method | __init__ | Конструктор.
Method | analyze | Функция анализа сообщения на соответствие регулярному выражению

def __init__(self, regexp): (source)
Конструктор.

Parameters | regexp | регулярное выражение для анализа (type: `unicode` )

def analyze(self, domain, message, attribute='text'): (source)
Функция анализа сообщения на соответствие регулярному выражению

Parameters | domain | домен, относительно которого идёт анализ (type: `IDomain` )
| message | сообщение (type: `spamfighter.interfaces.IMessage` )
| attribute | имя атрибута сообщения, содержащего текст (type: `str` )